lcvtoolbox.vision.geometry.primitives.axis\_angle.RPY
=====================================================

.. currentmodule:: lcvtoolbox.vision.geometry.primitives.axis_angle

.. autoclass:: RPY
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:
   :special-members: __init__, __str__, __repr__

   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~RPY.__init__
      ~RPY.compose
      ~RPY.copy
      ~RPY.from_degrees
      ~RPY.from_numpy
      ~RPY.from_rotation_matrix
      ~RPY.from_tuple
      ~RPY.interpolate
      ~RPY.inverse
      ~RPY.is_close
      ~RPY.normalize
      ~RPY.normalize_positive
      ~RPY.to_degrees
      ~RPY.to_radians
      ~RPY.to_rotation_matrix
      ~RPY.zeros
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~RPY.numpy
      ~RPY.pitch
      ~RPY.roll
      ~RPY.tuple
      ~RPY.yaw
   
   